@@ -9,18 +9,47 @@
 #' @include logging.R
 NULL
 
+set_libPaths <- function(lib.loc=NULL){
+  ol <- Sys.getenv('R_LIBS')
+  olib <- .libPaths()
+  res <- list(R_LIBS=ol, .libPaths=olib)
+  if( is_NA(lib.loc) ) return(res)
+  
+  # add lib path
+  if( is.null(lib.loc) ) lib.loc <- .libPaths()
+  if( is.character(lib.loc) ){
+    # current .libPaths
+    .libPaths(lib.loc)
+    # R_LIBS env variable
+    rlibs <- paste(lib.loc, collapse=.Platform$path.sep)
+    Sys.setenv(R_LIBS=rlibs)
+  }else if( is.list(lib.loc) ){
+    Sys.setenv(R_LIBS=lib.loc$R_LIBS)
+    .libPaths(lib.loc$.libPaths)
+  }
+  
+  res
+}
+
 #' Executing R Commands
 #' 
 #' \code{R.exec} executes a single R command via \code{\link{system2}}.
 #' 
 #' @param ... extra arguments that are concatenated and appended to 
 #' the command. 
+#' @param lib.loc logical that indicates if the current library locations
+#' should be used.
+#' If a character vector, then it is used as the library path specification.
 #' 
 #' @export
-R.exec <- function(...){
-	cmd <- paste(file.path(R.home(), 'bin', 'R'), ' ', ..., sep='', collapse='')
+R.exec <- function(..., lib.loc=NULL){
+	cmd <- paste(file.path(R.home('bin'), 'R'), ' ', ..., sep='', collapse='')
+	# add lib path
+	ol <- set_libPaths(lib.loc)
+	on.exit(set_libPaths(ol))
+
 	message(cmd)
-	system(cmd)
+	system(cmd, intern=interactive())
 }
 
 #' \code{R.CMD} executes R CMD commands.
@@ -113,9 +142,10 @@ packageEnv <- function(pkg, skip=FALSE, verbose=FALSE){
 		# return a correct environment (don't know why)
 		# - as.environment('package:*') will return the correct environment
 		# in dev mode.
-		env <- 
-		if( !is.null(path.package(pkg, quiet=TRUE)) ) asNamespace(pkg)
+		env <- if( is.environment(pkg) ) topenv(pkg)
+		else if( !is.null(path.package(pkg, quiet=TRUE)) ) asNamespace(pkg)
 		else if( isLoadingNamespace(pkg) ) getLoadingNamespace(env=TRUE)
+		else if( isNamespaceLoaded(pkg) ) asNamespace(pkg)
 		else if( pkg %in% search() ) as.environment(pkg)
 		else as.environment(str_c('package:', pkg)) # dev mode
 		return(env)
@@ -191,7 +221,7 @@ topns_name <- function(n=1L, strict=TRUE, unique=TRUE){
 	while( i <= nf && length(res) < n ){
 		e <- sys.frame(i)
 		if( !strict || !identical(e, .GlobalEnv) ){
-			pkg <- getPackageName(e, create=FALSE)
+			pkg <- methods::getPackageName(e, create=FALSE)
 			if( pkg != '' ){
 				res <- c(res, pkg)
 			}
@@ -202,7 +232,7 @@ topns_name <- function(n=1L, strict=TRUE, unique=TRUE){
 	if( !length(res) ){# try with packageEnv
 		e <- packageEnv(skip=TRUE)
 		if( isNamespace(e) ){
-			res <- getPackageName(e)
+			res <- methods::getPackageName(e)
 #			print(res)
 		}else{
 			#warning('Could not find top namespace.', immediate.=TRUE)
