@@ -851,7 +851,10 @@ expand_list <- function(x, ..., .exact=TRUE, .names=!.exact){
 	i <- match(names(defaults), names(x_ex))
 	if( length(w <- which(is.na(i))) ){
 		n <- names(defaults)[w]
-		lapply(n, function(m) x[[m]] <<- defaults[[m]])
+		lapply(n, function(m){
+			if( is.null(defaults[[m]]) ) x[m] <<- list(NULL) 
+			else x[[m]] <<- defaults[[m]]
+		})
 	}
 	
 	x
